==> tencentcloud-sdk-java-3.1.86-sources.jar: com/tencentcloudapi/iai/v20180301/models/EstimateCheckSimilarPersonCostTimeResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.iai.v20180301.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class EstimateCheckSimilarPersonCostTimeResponse extends AbstractModel{

    /**
    * 人员查重任务预估需要耗费时间。 单位为分钟。
    */
    @SerializedName("EstimatedTimeCost")
    @Expose
    private Long EstimatedTimeCost;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 人员查重任务预估需要耗费时间。 单位为分钟。 
     * @return EstimatedTimeCost 人员查重任务预估需要耗费时间。 单位为分钟。
     */
    public Long getEstimatedTimeCost() {
        return this.EstimatedTimeCost;
    }

    /**
     * Set 人员查重任务预估需要耗费时间。 单位为分钟。
     * @param EstimatedTimeCost 人员查重任务预估需要耗费时间。 单位为分钟。
     */
    public void setEstimatedTimeCost(Long EstimatedTimeCost) {
        this.EstimatedTimeCost = EstimatedTimeCost;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "EstimatedTimeCost", this.EstimatedTimeCost);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}

==> tencentcloud-sdk-java-3.1.425-sources.jar: com/tencentcloudapi/iai/v20180301/models/EstimateCheckSimilarPersonCostTimeResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.iai.v20180301.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class EstimateCheckSimilarPersonCostTimeResponse extends AbstractModel{

    /**
    * 人员查重任务预估需要耗费时间。 单位为分钟。
    */
    @SerializedName("EstimatedTimeCost")
    @Expose
    private Long EstimatedTimeCost;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 人员查重任务预估需要耗费时间。 单位为分钟。 
     * @return EstimatedTimeCost 人员查重任务预估需要耗费时间。 单位为分钟。
     */
    public Long getEstimatedTimeCost() {
        return this.EstimatedTimeCost;
    }

    /**
     * Set 人员查重任务预估需要耗费时间。 单位为分钟。
     * @param EstimatedTimeCost 人员查重任务预估需要耗费时间。 单位为分钟。
     */
    public void setEstimatedTimeCost(Long EstimatedTimeCost) {
        this.EstimatedTimeCost = EstimatedTimeCost;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public EstimateCheckSimilarPersonCostTimeResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public EstimateCheckSimilarPersonCostTimeResponse(EstimateCheckSimilarPersonCostTimeResponse source) {
        if (source.EstimatedTimeCost != null) {
            this.EstimatedTimeCost = new Long(source.EstimatedTimeCost);
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "EstimatedTimeCost", this.EstimatedTimeCost);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}
